@@ -11,6 +11,10 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
+from braket.pennylane_plugin.ahs_device import (  # noqa: F401
+    BraketAwsAhsDevice,
+    BraketLocalAhsDevice,
+)
 from braket.pennylane_plugin.braket_device import (  # noqa: F401
     BraketAwsQubitDevice,
     BraketLocalQubitDevice,
